=====================================
Installation and Notes for Developers
=====================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

If the contents do not show below, read them in :doc:`../../../README`
      
.. include:: ../../../README.rst
   :start-after: Install/Uninstall


   

